@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
-from .common import configure_logger
+# Author: fallingmeteorite
+from .common import configure_logger, ensure_config_loaded
 
 # Initialize logger configuration at module load
 configure_logger()
 
-from .config import ensure_config_loaded, config
-
 # Initialize the config dict
 ensure_config_loaded()
-# Import scheduler types
-from .variable import *
