@@ -4,19 +4,17 @@ import queue
 import threading
 import time
 import math
+
 from concurrent.futures import ProcessPoolExecutor, Future, BrokenExecutor
 from functools import partial
-from multiprocessing import Manager
+from multiprocessing.managers import DictProxy
 from typing import Callable, Dict, Tuple, Optional, Any
 
-from ..common import logger
-from ..config import config
+from ..common import logger, config
 from ..manager import task_status_manager, SharedTaskDict
-from ..control import ThreadTerminator, ProcessTaskManager, StopException, ThreadingTimeout, TimeoutException, \
-    ThreadSuspender
-from ..utils import worker_initializer
-
-from ..scheduler_tools import TaskCounter
+from ..control import ProcessTaskManager
+from ..handling import ThreadTerminator, StopException, ThreadSuspender, TimeoutException, ThreadingTimeout
+from .utils import exit_cleanup_liner, TaskCounter, shared_task_info, get_param_count
 
 _task_counter = TaskCounter("cpu_liner_task")
 _threadsuspender = ThreadSuspender()
@@ -25,30 +23,30 @@ _threadterminator = ThreadTerminator()
 
 def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
                   task_status_queue: queue.Queue,
-                  task_signal_transmission: queue.Queue) -> Any:
+                  task_signal_transmission: DictProxy) -> Any:
     """
     Execute a task and handle its status.
 
     Args:
-        task (Tuple[bool, str, str, Callable, Tuple, Dict]): A tuple containing task details.
-            - timeout_processing (bool): Whether timeout processing is enabled.
-            - task_name (str): Name of the task.
-            - task_id (str): ID of the task.
-            - func (Callable): The function to execute.
-            - args (Tuple): Arguments to pass to the function.
-            - kwargs (Dict): Keyword arguments to pass to the function.
-        task_status_queue (queue.Queue): Queue to update task status.
-        task_signal_transmission (queue.Queue): Queue to transmission signal.
+        task: A tuple containing task details.
+            - timeout_processing: Whether timeout processing is enabled.
+            - task_name: Name of the task.
+            - task_id: ID of the task.
+            - func: The function to execute.
+            - args: Arguments to pass to the function.
+            - kwargs: Keyword arguments to pass to the function.
+        task_status_queue: Queue to update task status.
+        task_signal_transmission: Dict to transmission signal.
 
     Returns:
-        Any: Result of the task execution or error message.
+        Result of the task execution or error message.
     """
     # Create a shared dictionary
     _sharedtaskdict = SharedTaskDict()
 
     timeout_processing, task_name, task_id, func, priority, args, kwargs = task
     task_manager = ProcessTaskManager(task_signal_transmission)
-    return_results = None
+    result = None
 
     try:
         with _threadterminator.terminate_control() as terminate_ctx:
@@ -56,53 +54,51 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
                 task_manager.add(terminate_ctx, pause_ctx, task_id)
 
                 task_status_queue.put(("running", task_id, None, time.time(), None, None, None))
-                logger.debug(f"Start running cpu linear task, task ID: {task_id}")
+                logger.debug(f"Start running task, task ID: {task_id}")
                 if timeout_processing:
                     with ThreadingTimeout(seconds=config["watch_dog_time"], swallow_exc=False):
                         # Whether to pass in the task manager to facilitate other thread management
-                        if config["thread_management"]:
+                        # Check whether the function needs to use hyperthreading
+                        if config["thread_management"] and get_param_count(func, *args, **kwargs):
                             share_info = (task_manager, _threadterminator, StopException, ThreadingTimeout,
                                           TimeoutException, _threadsuspender, task_status_queue)
-                            return_results = func(share_info, _sharedtaskdict, task_signal_transmission, *args,
-                                                  **kwargs)
+                            result = func(share_info, _sharedtaskdict, task_signal_transmission, *args,
+                                          **kwargs)
                         else:
-                            return_results = func(*args, **kwargs)
+                            result = func(*args, **kwargs)
                 else:
-                    return_results = func(*args, **kwargs)
-
+                    result = func(*args, **kwargs)
 
+        task_manager.remove(task_id)
     except (StopException, KeyboardInterrupt):
-        logger.warning(f"Cpu linear task | {task_id} | cancelled, forced termination")
+        logger.warning(f"task | {task_id} | cancelled, forced termination")
         task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
-        return_results = "error happened"
+        result = "cancelled action"
 
     except TimeoutException:
-        logger.warning(f"Cpu linear task | {task_id} | timed out, forced termination")
+        # Terminate all other threads under the main thread
+        logger.warning(f"task | {task_id} | timed out, forced termination")
         task_status_queue.put(("timeout", task_id, None, None, None, None, None))
-        return_results = "error happened"
+        result = "timeout action"
 
     except Exception as e:
         if config["exception_thrown"]:
             raise
 
-        logger.error(f"Cpu linear task | {task_id} | execution failed: {e}")
+        logger.error(f"task | {task_id} | execution failed: {e}")
         task_status_queue.put(("failed", task_id, None, None, None, e, None))
-        return_results = "error happened"
+        result = "failed action"
 
     finally:
-        task_manager.remove(task_id)
-
         # Terminate all other threads under the main thread
         if config["thread_management"]:
-            task_manager.terminate_task_all()
+            task_manager.terminate_branch_task()
 
-        if return_results != "error happened":
-            try:
-                task_status_queue.put(("completed", task_id, None, None, time.time(), None, None))
-            except BrokenPipeError:
-                pass
+        # Remove main thread logging
+        if task_manager.check(task_id):
+            task_manager.remove(task_id)
 
-        return return_results
+    return result
 
 
 class CpuLinerTask:
@@ -115,7 +111,6 @@ class CpuLinerTask:
         '_scheduler_started', '_scheduler_stop_event', '_scheduler_thread',
         '_idle_timer', '_idle_timeout', '_idle_timer_lock',
         '_task_results',
-        '_manager', '_task_status_queue', '_task_signal_transmission',
         '_executor', '_status_thread'
     ]
 
@@ -140,10 +135,6 @@ class CpuLinerTask:
 
         self._task_results: Dict[str, Any] = {}  # Store task return results, keep up to 2 results for each task ID
 
-        self._manager = Manager()
-        self._task_status_queue = self._manager.Queue()  # Queue for task status updates
-        self._task_signal_transmission = self._manager.Queue()  # Queue for task status updates
-
         self._executor: Optional[ProcessPoolExecutor] = None
 
         # Start a thread to handle task status updates
@@ -153,10 +144,10 @@ class CpuLinerTask:
         """
         Handle task status updates from the task status queue.
         """
-        while not self._scheduler_stop_event.is_set() or not self._task_status_queue.empty():
+        while not self._scheduler_stop_event.is_set() or not shared_task_info.task_status_queue.empty():
             try:
-                if not self._task_status_queue.empty():
-                    task = self._task_status_queue.get(timeout=0.1)
+                if not shared_task_info.task_status_queue.empty():
+                    task = shared_task_info.task_status_queue.get(timeout=0.1)
                     status, task_id, task_name, start_time, end_time, error, timeout_processing = task
                     task_status_manager.add_task_status(task_id, task_name, status, start_time, end_time, error,
                                                         timeout_processing, "cpu_liner_task")
@@ -164,7 +155,10 @@ class CpuLinerTask:
             except (queue.Empty, ValueError):
                 pass  # Ignore empty queue exceptions
             finally:
-                time.sleep(0.1)
+                try:
+                    time.sleep(0.1)
+                except KeyboardInterrupt:
+                    pass
 
     def add_task(self,
                  timeout_processing: bool,
@@ -177,19 +171,20 @@ class CpuLinerTask:
         Add the task to the scheduler.
 
         Args:
-            timeout_processing (bool): Whether timeout processing is enabled.
-            task_name (str): Task name.
-            task_id (str): Task ID.
-            func (Callable): The function to execute.
-            priority (str): Mission importance level.
+            timeout_processing: Whether timeout processing is enabled.
+            task_name: Task name.
+            task_id: Task ID.
+            func: The function to execute.
+            priority: Mission importance level.
             *args: Arguments to pass to the function.
             **kwargs: Keyword arguments to pass to the function.
 
         Returns:
-            bool: Whether the task was successfully added.
+            Whether the task was successfully added.
         """
         try:
             with self._scheduler_lock:
+                shared_task_info.task_status_queue.put(("queuing", task_id, None, None, None, None, None))
                 if not _task_counter.is_high_priority(priority):
                     if self._task_queue.qsize() >= config["cpu_liner_task"]:
                         return False
@@ -197,14 +192,14 @@ class CpuLinerTask:
                     if task_name in [details[1] for details in self._running_tasks.values()]:
                         return False
                 else:
-                    if not _task_counter.add(math.ceil(config["cpu_liner_task"])):
+                    if not _task_counter.add_count(math.ceil(config["cpu_liner_task"])):
                         return False
 
                 if self._scheduler_stop_event.is_set() and not self._scheduler_started:
                     self._join_scheduler_thread()
 
                 # Reduce the granularity of the lock
-                self._task_status_queue.put(("waiting", task_id, None, None, None, None, None))
+                shared_task_info.task_status_queue.put(("waiting", task_id, None, None, None, None, None))
 
                 self._task_queue.put((timeout_processing, task_name, task_id, func, priority, args, kwargs))
 
@@ -218,7 +213,7 @@ class CpuLinerTask:
 
                 return True
         except Exception as e:
-            logger.debug(f"Cpu linear task | {task_id} | error adding task: {e}")
+            logger.error(f"task | {task_id} | error adding task: {e}")
             return e
 
     def _start_scheduler(self) -> None:
@@ -236,19 +231,20 @@ class CpuLinerTask:
         """
         Stop the scheduler thread.
 
-        :param force_cleanup: If True, force stop all tasks and clear the queue.
-                              If False, gracefully stop the scheduler (e.g., due to idle timeout).
-        :param system_operations: Boolean indicating if this stop is due to system operations.
+        Args:
+            force_cleanup: If True, force stop all tasks and clear the queue.
+                          If False, gracefully stop the scheduler (e.g., due to idle timeout).
+            system_operations: Boolean indicating if this stop is due to system operations.
         """
         with self._scheduler_lock:
             # Check if there are any running tasks
             if not self._task_queue.empty() or not len(self._running_tasks) == 0:
                 if system_operations:
-                    logger.debug(f"Cpu liner task | detected running tasks | stopping operation terminated")
+                    logger.warning(f"Cpu liner task | detected running tasks | stopping operation terminated")
                     return None
 
             if force_cleanup:
-                logger.debug("Force stopping scheduler and cleaning up tasks")
+                logger.warning("Force stopping scheduler and cleaning up tasks")
                 self.stop_all_running_task()
 
             # Ensure the executor is properly shut down
@@ -269,9 +265,6 @@ class CpuLinerTask:
             self._join_scheduler_thread()
             self._status_thread.join()
 
-            # Ensure the manager is properly shut down
-            self._manager.shutdown()
-
             # Reset state variables
             self._scheduler_started = False
             self._scheduler_stop_event.clear()
@@ -284,17 +277,20 @@ class CpuLinerTask:
 
     def stop_all_running_task(self):
         for task_id in self._running_tasks.keys():
-            self._task_signal_transmission.put((task_id, "kill"))
+            shared_task_info.task_signal_transmission[task_id] = ["kill"]
 
-        while not self._task_signal_transmission.qsize() == 0:
-            time.sleep(0.1)
+        while not len(shared_task_info.task_signal_transmission.items()) == 0:
+            try:
+                time.sleep(0.1)
+            except KeyboardInterrupt:
+                pass
 
     def _scheduler(self) -> None:
         """
         Scheduler function, fetch tasks from the task queue and submit them to the process pool for execution.
         """
         with ProcessPoolExecutor(max_workers=int(config["cpu_liner_task"] + math.ceil(config["cpu_liner_task"] / 2)),
-                                 initializer=worker_initializer) as executor:
+                                 initializer=exit_cleanup_liner) as executor:
             self._executor = executor
             while not self._scheduler_stop_event.is_set():
                 with self._condition:
@@ -311,11 +307,11 @@ class CpuLinerTask:
 
                 timeout_processing, task_name, task_id, func, priority, args, kwargs = task
                 with self._lock:
-                    future = executor.submit(_execute_task, task, self._task_status_queue,
-                                             self._task_signal_transmission)
+                    future = executor.submit(_execute_task, task, shared_task_info.task_status_queue,
+                                             shared_task_info.task_signal_transmission)
                     self._running_tasks[task_id] = [future, task_name, priority]
                     future.add_done_callback(partial(self._task_done, task_id))
-                _task_counter.schedule_tasks(self._running_tasks)
+                _task_counter.schedule_tasks(self._running_tasks, self.pause_task, self.resume_task)
 
     def _task_done(self,
                    task_id: str,
@@ -323,22 +319,42 @@ class CpuLinerTask:
         """
         Callback function after a task is completed.
 
-        :param task_id: Task ID.
-        :param future: Future object corresponding to the task.
+        Args:
+            task_id: Task ID.
+            future: Future object corresponding to the task.
         """
+        result = None
         try:
             result = future.result()  # Get the task result, where the exception will be thrown
-            # The storage task returns a result, and a maximum of two results are retained
-            if result is not None:
-                if result != "error happened":
-                    with self._lock:
-                        self._task_results[task_id] = result
+
         except (KeyboardInterrupt, BrokenExecutor):
             # Prevent problems caused by exit errors
-            logger.debug(f"Cpu linear task | {task_id} | cancelled, forced termination")
-            self._task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
+            logger.warning(f"task | {task_id} | cancelled, forced termination")
+            shared_task_info.task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
+            result = "cancelled action"
+
+        except Exception as e:
+            if config["exception_thrown"]:
+                raise
+
+            logger.error(f"task | {task_id} | execution failed: {e}")
+            shared_task_info.task_status_queue.put(("failed", task_id, None, None, None, e, None))
+            result = "failed action"
 
         finally:
+            # The storage task returns a result, and a maximum of two results are retained
+            if result not in ["timeout action", "cancelled action", "failed action"]:
+                shared_task_info.task_status_queue.put(("completed", task_id, None, None, None, None, None))
+                if result is not None:
+                    with self._lock:
+                        self._task_results[task_id] = [result, time.time()]
+                else:
+                    with self._lock:
+                        self._task_results[task_id] = ["completed action", time.time()]
+            else:
+                with self._lock:
+                    self._task_results[task_id] = [result, time.time()]
+
             # Make sure the Future object is deleted
             with self._lock:
                 if task_id in self._running_tasks:
@@ -355,6 +371,7 @@ class CpuLinerTask:
             if self._idle_timer is not None:
                 self._idle_timer.cancel()
             self._idle_timer = threading.Timer(self._idle_timeout, self.stop_scheduler, args=(False, True,))
+            self._idle_timer.daemon = True
             self._idle_timer.start()
 
     def _cancel_idle_timer(self) -> None:
@@ -381,72 +398,95 @@ class CpuLinerTask:
             self._scheduler_thread.join()
 
     def force_stop_task(self,
-                        task_id: str,
-                        main_task: bool) -> bool:
+                        task_id: str) -> bool:
         """
         Force stop a task by its task ID.
 
-        :param task_id: Task ID.
-        :param main_task: If the task is terminated as the main task, the flag is True.
+        Args:
+            task_id: Task ID.
 
-        :return: bool: Whether the task was successfully force stopped.
+        Returns:
+            Whether the task was successfully force stopped.
         """
-        if self._running_tasks.get(task_id) is None and main_task:
-            logger.debug(f"Cpu linear task | {task_id} | does not exist or is already completed")
-            return False
-        # Handling situations on non-main threads
-        if main_task:
+
+        if self._running_tasks.get(task_id) is None:
+            if not config["thread_management"]:
+                logger.warning(f"task | {task_id} | does not exist or is already completed")
+                return False
+
+        if self._running_tasks.get(task_id) is None:
+            # First ensure that the task is not paused.
+            shared_task_info.task_signal_transmission[task_id] = ["resume", "kill"]
+
+        else:
+            # Handling situations on non-main threads
             future = self._running_tasks[task_id][0]
             if not future.running():
                 future.cancel()
             else:
-                self._task_signal_transmission.put((task_id, "kill"))
-        else:
-            self._task_signal_transmission.put((task_id, "kill"))
-
-        self._task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
-        with self._lock:
-            if task_id in self._task_results:
-                del self._task_results[task_id]
+                # First ensure that the task is not paused.
+                shared_task_info.task_signal_transmission[task_id] = ["resume", "kill"]
 
+        shared_task_info.task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
         return True
 
-    def pause_and_resume_task(self,
-                              task_id: str, action: str) -> bool:
+    def pause_task(self,
+                   task_id: str) -> bool:
         """
-        pause and resume a task by its task ID.
+        Pause a task by its task ID.
 
-        :param task_id: Task ID.
-        :param action: Task action.
-        :return: bool: Whether the task was successfully pause and resume.
+        Args:
+            task_id: Task ID.
+
+        Returns:
+            Whether the task was successfully paused.
         """
-        if self._running_tasks.get(task_id) is None:
-            logger.debug(f"Cpu linear task | {task_id} | does not exist or is already completed")
+        if self._running_tasks.get(task_id) is None and not config["thread_management"]:
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
             return False
 
-        else:
-            if action == "pause":
-                self._task_signal_transmission.put((task_id, "pause"))
-                self._task_status_queue.put(("waiting", task_id, None, None, None, None, None))
-            elif action == "resume":
-                self._task_signal_transmission.put((task_id, "resume"))
-                self._task_status_queue.put(("running", task_id, None, None, None, None, None))
+        shared_task_info.task_signal_transmission[task_id] = ["pause"]
+        shared_task_info.task_status_queue.put(("paused", task_id, None, None, None, None, None))
+
+        return True
+
+    def resume_task(self,
+                    task_id: str) -> bool:
+        """
+        Resume a task by its task ID.
+
+        Args:
+            task_id: Task ID.
+
+        Returns:
+            Whether the task was successfully resumed.
+        """
+        if self._running_tasks.get(task_id) is None and not config["thread_management"]:
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
+            return False
+
+        shared_task_info.task_signal_transmission[task_id] = ["resume"]
+        shared_task_info.task_status_queue.put(("running", task_id, None, None, None, None, None))
 
         return True
 
-    # Obtain the information returned by the corresponding task
     def get_task_result(self,
                         task_id: str) -> Optional[Any]:
         """
         Get the result of a task. If there is a result, return and delete the oldest result; if no result, return None.
 
-        :param task_id: Task ID.
+        Args:
+            task_id: Task ID.
 
-        :return: Optional[Any]: Task return result, or None if the task is not completed or does not exist.
+        Returns:
+            Task return result, or None if the task is not completed or does not exist.
         """
         if task_id in self._task_results:
+            result = self._task_results[task_id][0]
             with self._lock:
-                result = self._task_results[task_id]  # Return and delete the oldest result
                 del self._task_results[task_id]
                 return result
         return None
+
+
+cpu_liner_task = CpuLinerTask()
