@@ -4,20 +4,20 @@ import queue
 import threading
 import math
 import time
+
 from concurrent.futures import ThreadPoolExecutor, Future
 from functools import partial
 from typing import Callable, Dict, Tuple, Optional, Any
 
-from ..common import logger
-from ..config import config
+from ..common import logger, config
 from ..manager import task_status_manager
-from ..control import ThreadTaskManager, ThreadTerminator, StopException, ThreadingTimeout, TimeoutException, \
-    ThreadSuspender
-from ..scheduler_tools import TaskCounter
+from ..control import ThreadTaskManager
+from ..handling import TimeoutException, ThreadSuspender, StopException, ThreadingTimeout, ThreadTerminator
+from .utils import TaskCounter
 
 # Create Manager instance
-_task_manager = ThreadTaskManager()
 _task_counter = TaskCounter("io_liner_task")
+_task_manager = ThreadTaskManager()
 _threadsuspender = ThreadSuspender()
 _threadterminator = ThreadTerminator()
 
@@ -27,16 +27,16 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict]) -> Any:
     Execute a task and handle its status.
 
     Args:
-        task (Tuple[bool, str, str, Callable, Tuple, Dict]): A tuple containing task details.
-            - timeout_processing (bool): Whether timeout processing is enabled.
-            - task_name (str): Name of the task.
-            - task_id (str): ID of the task.
-            - func (Callable): The function to execute.
-            - args (Tuple): Arguments to pass to the function.
-            - kwargs (Dict): Keyword arguments to pass to the function.
+        task: A tuple containing task details.
+            - timeout_processing: Whether timeout processing is enabled.
+            - task_name: Name of the task.
+            - task_id: ID of the task.
+            - func: The function to execute.
+            - args: Arguments to pass to the function.
+            - kwargs: Keyword arguments to pass to the function.
 
     Returns:
-        Any: Result of the task execution or error message.
+        Result of the task execution or error message.
     """
     timeout_processing, task_name, task_id, func, priority, args, kwargs = task
 
@@ -48,7 +48,7 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict]) -> Any:
                 _task_manager.add(None, terminate_ctx, pause_ctx, task_id)
 
                 task_status_manager.add_task_status(task_id, None, "running", time.time(), None, None, None, None)
-                logger.debug(f"Start running io linear task, task ID: {task_id}")
+                logger.debug(f"Start running task, task ID: {task_id}")
 
                 if timeout_processing:
                     with ThreadingTimeout(seconds=config["watch_dog_time"], swallow_exc=False):
@@ -58,24 +58,26 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict]) -> Any:
 
         _task_manager.remove(task_id)
     except TimeoutException:
-        logger.warning(f"Io linear task | {task_id} | timed out, forced termination")
+        logger.warning(f"task | {task_id} | timed out, forced termination")
         task_status_manager.add_task_status(task_id, None, "timeout", None, None, None, None, None)
-        return_results = "error happened"
+        return_results = "timeout action"
     except StopException:
-        logger.warning(f"Io linear task | {task_id} | was cancelled")
+        logger.warning(f"task | {task_id} | was cancelled")
         task_status_manager.add_task_status(task_id, None, "cancelled", None, None, None, None, None)
+        return_results = "cancelled action"
     except Exception as e:
         if config["exception_thrown"]:
             raise
 
-        logger.error(f"Io linear task | {task_id} | execution failed: {e}")
+        logger.error(f"task | {task_id} | execution failed: {e}")
         task_status_manager.add_task_status(task_id, None, "failed", None, None, e, None, None)
-        return_results = "error happened"
+        return_results = "failed action"
 
     finally:
         if _task_manager.check(task_id):
             _task_manager.remove(task_id)
-        return return_results
+
+    return return_results
 
 
 class IoLinerTask:
@@ -125,20 +127,20 @@ class IoLinerTask:
         Add a task to the task queue.
 
         Args:
-            timeout_processing (bool): Whether to enable timeout processing.
-            task_name (str): Task name (can be repeated).
-            task_id (str): Task ID (must be unique).
-            func (Callable): Task function.
-            priority (str): Mission importance level.
+            timeout_processing: Whether to enable timeout processing.
+            task_name: Task name (can be repeated).
+            task_id: Task ID (must be unique).
+            func: Task function.
+            priority: Mission importance level.
             *args: Positional arguments for the task function.
             **kwargs: Keyword arguments for the task function.
 
         Returns:
-            bool: Whether the task was successfully added.
+            Whether the task was successfully added.
         """
         try:
             with self._scheduler_lock:
-
+                task_status_manager.add_task_status(task_id, None, "queuing", None, None, None, None, "io_liner_task")
                 if not _task_counter.is_high_priority(priority):
 
                     if self._task_queue.qsize() >= config["io_liner_task"]:
@@ -148,14 +150,14 @@ class IoLinerTask:
                         return False
 
                 else:
-                    if not _task_counter.add(math.ceil(config["io_liner_task"])):
+                    if not _task_counter.add_count(math.ceil(config["io_liner_task"])):
                         return False
 
                 if self._scheduler_stop_event.is_set() and not self._scheduler_started:
                     self._join_scheduler_thread()
 
                 # Reduce the granularity of the lock
-                task_status_manager.add_task_status(task_id, None, "waiting", None, None, None, None, "io_liner_task")
+                task_status_manager.add_task_status(task_id, None, "waiting", None, None, None, None, None)
 
                 self._task_queue.put((timeout_processing, task_name, task_id, func, priority, args, kwargs))
 
@@ -169,7 +171,7 @@ class IoLinerTask:
 
                 return True
         except Exception as e:
-            logger.debug(f"Io linear task | {task_id} | error adding task: {e}")
+            logger.error(f"task | {task_id} | error adding task: {e}")
             return e
 
     # Start the scheduler
@@ -188,19 +190,20 @@ class IoLinerTask:
         """
         Stop the scheduler thread.
 
-        :param force_cleanup: If True, force stop all tasks and clear the queue.
-                              If False, gracefully stop the scheduler (e.g., due to idle timeout).
-        :param system_operations: System execution metrics.
+        Args:
+            force_cleanup: If True, force stop all tasks and clear the queue.
+                          If False, gracefully stop the scheduler (e.g., due to idle timeout).
+            system_operations: System execution metrics.
         """
         with self._scheduler_lock:
             # Check if all tasks are completed
             if not self._task_queue.empty() or not len(self._running_tasks) == 0:
                 if system_operations:
-                    logger.debug(f"Io liner task was detected to be running, and the task stopped terminating")
+                    logger.warning(f"task was detected to be running, and the task stopped terminating")
                     return None
 
             if force_cleanup:
-                logger.debug("Force stopping scheduler and cleaning up tasks")
+                logger.warning("Force stopping scheduler and cleaning up tasks")
                 # Force stop all running tasks
                 _task_manager.terminate_all_tasks()
                 self._scheduler_stop_event.set()
@@ -254,7 +257,7 @@ class IoLinerTask:
                     self._running_tasks[task_id] = [future, task_name, priority]
 
                     future.add_done_callback(partial(self._task_done, task_id))
-                _task_counter.schedule_tasks(self._running_tasks)
+                _task_counter.schedule_tasks(self._running_tasks, self.pause_task, self.resume_task)
 
     # A function that executes a task
     def _task_done(self,
@@ -263,18 +266,25 @@ class IoLinerTask:
         """
         Callback function after a task is completed.
 
-        :param task_id: Task ID.
-        :param future: Future object corresponding to the task.
+        Args:
+            task_id: Task ID.
+            future: Future object corresponding to the task.
         """
         try:
             result = future.result()  # Get task result, exceptions will be raised here
 
             # Store task return results, keep up to 2 results
-            if result != "error happened":
+            if result not in ["timeout action", "cancelled action", "failed action"]:
                 if result is not None:
                     with self._lock:
-                        self._task_results[task_id] = result
+                        self._task_results[task_id] = [result, time.time()]
+                else:
+                    with self._lock:
+                        self._task_results[task_id] = ["completed action", time.time()]
                 task_status_manager.add_task_status(task_id, None, "completed", None, time.time(), None, None, None)
+            else:
+                with self._lock:
+                    self._task_results[task_id] = [result, time.time()]
 
         finally:
             # Ensure the Future object is deleted
@@ -296,6 +306,7 @@ class IoLinerTask:
             if self._idle_timer is not None:
                 self._idle_timer.cancel()
             self._idle_timer = threading.Timer(self._idle_timeout, self.stop_scheduler, args=(False, True,))
+            self._idle_timer.daemon = True
             self._idle_timer.start()
 
     def _cancel_idle_timer(self) -> None:
@@ -326,45 +337,64 @@ class IoLinerTask:
         """
         Force stop a task by its task ID.
 
-        :param task_id: Task ID.
+        Args:
+            task_id: Task ID.
 
-        :return: bool: Whether the task was successfully force stopped.
+        Returns:
+            Whether the task was successfully force stopped.
         """
         if not self._running_tasks.get(task_id, None):
-            logger.debug(f"Io linear task | {task_id} | does not exist or is already completed")
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
             return False
 
         future = self._running_tasks[task_id][0]
         if not future.running():
             future.cancel()
         else:
+            # First ensure that the task is not paused.
+            _task_manager.resume_task(task_id)
             _task_manager.terminate_task(task_id)
 
         task_status_manager.add_task_status(task_id, None, "cancelled", None, None, None, None, None)
-        with self._lock:
-            if task_id in self._task_results:
-                del self._task_results[task_id]
         return True
 
-    def pause_and_resume_task(self,
-                              task_id: str, action: str) -> bool:
+    def pause_task(self,
+                   task_id: str) -> bool:
         """
-        Pause and resume a task by its task ID.
-        :param task_id: Task ID.
-        :param action: Task action.
-        :return: bool: Whether the task was successfully pause and resume.
+        Pause a task by its task ID.
+
+        Args:
+            task_id: Task ID.
+
+        Returns:
+            Whether the task was successfully paused.
         """
-        if not self._running_tasks.get(task_id, None):
-            logger.debug(f"Io linear task | {task_id} | does not exist or is already completed")
+        if self._running_tasks.get(task_id) is None and not config["thread_management"]:
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
             return False
 
-        else:
-            if action == "pause":
-                _task_manager.pause_task(task_id)
-                task_status_manager.add_task_status(task_id, None, "waiting", None, None, None, None, None)
-            elif action == "resume":
-                _task_manager.resume_task(task_id)
-                task_status_manager.add_task_status(task_id, None, "running", None, None, None, None, None)
+        _task_manager.pause_task(task_id)
+        task_status_manager.add_task_status(task_id, None, "paused", None, None, None, None, None)
+
+        return True
+
+    def resume_task(self,
+                    task_id: str) -> bool:
+        """
+        Resume a task by its task ID.
+
+        Args:
+            task_id: Task ID.
+
+        Returns:
+            Whether the task was successfully resumed.
+        """
+        if self._running_tasks.get(task_id) is None and not config["thread_management"]:
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
+            return False
+
+        _task_manager.resume_task(task_id)
+        task_status_manager.add_task_status(task_id, None, "running", None, None, None, None, None)
 
         return True
 
@@ -374,13 +404,18 @@ class IoLinerTask:
         """
         Get the result of a task. If there is a result, return and delete the oldest result; if no result, return None.
 
-        :param task_id: Task ID.
+        Args:
+            task_id: Task ID.
 
-        :return: Optional[Any]: Task return result, or None if the task is not completed or does not exist.
+        Returns:
+            Task return result, or None if the task is not completed or does not exist.
         """
         if task_id in self._task_results:
-            result = self._task_results[task_id]
+            result = self._task_results[task_id][0]
             with self._lock:
                 del self._task_results[task_id]
             return result
         return None
+
+
+io_liner_task = IoLinerTask()
