@@ -3,16 +3,16 @@
 import queue
 import threading
 import time
+
 from concurrent.futures import ThreadPoolExecutor, Future
 from datetime import datetime, timedelta
 from functools import partial
 from typing import Callable, Dict, List, Tuple, Optional, Any
 
-from ..common import logger
-from ..config import config
+from ..common import logger, config
 from ..manager import task_status_manager
-from ..control import ThreadTaskManager, ThreadTerminator, StopException, ThreadingTimeout, TimeoutException, \
-    ThreadSuspender
+from ..control import ThreadTaskManager
+from ..handling import ThreadTerminator, StopException, ThreadingTimeout, TimeoutException, ThreadSuspender
 
 # Create Manager instance
 _task_manager = ThreadTaskManager()
@@ -25,16 +25,16 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict]) -> Any:
     Execute a task and handle its status.
 
     Args:
-        task (Tuple[bool, str, str, Callable, Tuple, Dict]): A tuple containing task details.
-            - timeout_processing (bool): Whether timeout processing is enabled.
-            - task_name (str): Name of the task.
-            - task_id (str): ID of the task.
-            - func (Callable): The function to execute.
-            - args (Tuple): Arguments to pass to the function.
-            - kwargs (Dict): Keyword arguments to pass to the function.
+        task: A tuple containing task details.
+            - timeout_processing: Whether timeout processing is enabled.
+            - task_name: Name of the task.
+            - task_id: ID of the task.
+            - func: The function to execute.
+            - args: Arguments to pass to the function.
+            - kwargs: Keyword arguments to pass to the function.
 
     Returns:
-        Any: Result of the task execution or error message.
+        Result of the task execution or error message.
     """
     timeout_processing, task_name, task_id, func, args, kwargs = task
 
@@ -46,7 +46,7 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict]) -> Any:
                 task_status_manager.add_task_status(task_id, None, "running", time.time(), None, None,
                                                     None, None)
 
-            logger.debug(f"Start running timer task, task ID: {task_id}")
+            logger.debug(f"Start running task, task ID: {task_id}")
 
             if timeout_processing:
                 with ThreadingTimeout(seconds=config["watch_dog_time"], swallow_exc=False):
@@ -58,28 +58,29 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict]) -> Any:
             _task_manager.remove(task_id)
 
     except TimeoutException:
-        logger.warning(f"Timer task | {task_id} | timed out, forced termination")
+        logger.warning(f"task | {task_id} | timed out, forced termination")
         task_status_manager.add_task_status(task_id, None, "timeout", None, None, None,
                                             None, None)
-        return_results = "error happened"
+        return_results = "timeout action"
     except StopException:
-        logger.warning(f"Timer task | {task_id} | cancelled, forced termination")
+        logger.warning(f"task | {task_id} | cancelled, forced termination")
         task_status_manager.add_task_status(task_id, None, "cancelled", None, None, None,
                                             None, None)
-        return_results = "error happened"
+        return_results = "cancelled action"
     except Exception as e:
         if config["exception_thrown"]:
             raise
 
-        logger.error(f"Timer task | {task_id} | execution failed: {e}")
+        logger.error(f"task | {task_id} | execution failed: {e}")
         task_status_manager.add_task_status(task_id, None, "failed", None, None, e,
                                             None, None)
-        return_results = "error happened"
+        return_results = "failed action"
 
     finally:
         if _task_manager.check(task_id):
             _task_manager.remove(task_id)
-        return return_results
+
+    return return_results
 
 
 class TimerTask:
@@ -130,20 +131,21 @@ class TimerTask:
         Add a task to the task queue.
 
         Args:
-            delay (Optional[int]): Delay in seconds before the task should be executed (only once).
-            daily_time (Optional[str]): Specific time in "HH:MM" format for daily task execution.
-            timeout_processing (bool): Whether to enable timeout processing.
-            task_name (str): Task name (can be repeated).
-            task_id (str): Task ID (must be unique).
-            func (Callable): Task function.
+            delay: Delay in seconds before the task should be executed (only once).
+            daily_time: Specific time in "HH:MM" format for daily task execution.
+            timeout_processing: Whether to enable timeout processing.
+            task_name: Task name (can be repeated).
+            task_id: Task ID (must be unique).
+            func: Task function.
             *args: Positional arguments for the task function.
             **kwargs: Keyword arguments for the task function.
 
         Returns:
-            bool: Whether the task was successfully added.
+            Whether the task was successfully added.
         """
         try:
             with self._scheduler_lock:
+                task_status_manager.add_task_status(task_id, None, "queuing", None, None, None, None, "timer_task")
                 if self._scheduler_stop_event.is_set() and not self._scheduler_started:
                     self._join_scheduler_thread()
 
@@ -159,11 +161,11 @@ class TimerTask:
                         scheduled_time += timedelta(days=1)
                     execution_time = scheduled_time.timestamp()
                 else:
-                    logger.debug(f"Timer task | {task_id} | no scheduling parameters provided")
-                    return f"Timer task | {task_id} | no scheduling parameters provided"
+                    logger.error(f"task | {task_id} | no scheduling parameters provided")
+                    return False
                 # Reduce the granularity of the lock
                 task_status_manager.add_task_status(task_id, None, "waiting", None, None, None,
-                                                    None, "timer_task")
+                                                    None, None)
 
                 self._task_queue.put((execution_time, timeout_processing, task_name, task_id, func, args, kwargs))
 
@@ -177,7 +179,7 @@ class TimerTask:
 
                 return True
         except Exception as e:
-            logger.debug(f"Error adding task | {task_id} |: {e}")
+            logger.error(f"Error adding task | {task_id} |: {e}")
             return e
 
     # Start the scheduler
@@ -196,19 +198,20 @@ class TimerTask:
         """
         Stop the scheduler thread.
 
-        :param force_cleanup: If True, force stop all tasks and clear the queue.
-                              If False, gracefully stop the scheduler (e.g., due to idle timeout).
-        :param system_operations: System execution metrics.
+        Args:
+            force_cleanup: If True, force stop all tasks and clear the queue.
+                          If False, gracefully stop the scheduler (e.g., due to idle timeout).
+            system_operations: System execution metrics.
         """
         with self._scheduler_lock:
             # Check if all tasks are completed
             if not self._task_queue.empty() or not len(self._running_tasks) == 0:
                 if system_operations:
-                    logger.debug(f"Timer task was detected to be running, and the task stopped terminating")
+                    logger.warning(f"task was detected to be running, and the task stopped terminating")
                     return None
 
             if force_cleanup:
-                logger.debug("Force stopping scheduler and cleaning up tasks")
+                logger.warning("Force stopping scheduler and cleaning up tasks")
                 # Force stop all running tasks
                 _task_manager.terminate_all_tasks()
                 self._scheduler_stop_event.set()
@@ -280,18 +283,28 @@ class TimerTask:
         """
         Callback function after a task is completed.
 
-        :param task_id: Task ID.
-        :param timeout_processing: Whether timeout processing is enabled.
-        :param task_name: Task name.
-        :param func: Task function.
-        :param args: Positional arguments for the task function.
-        :param kwargs: Keyword arguments for the task function.
-        :param future: Future object corresponding to the task.
+        Args:
+            task_id: Task ID.
+            timeout_processing: Whether timeout processing is enabled.
+            task_name: Task name.
+            func: Task function.
+            args: Positional arguments for the task function.
+            kwargs: Keyword arguments for the task function.
+            future: Future object corresponding to the task.
         """
         try:
             result = future.result()  # Get task result, exceptions will be raised here
-            if result != "error happened":
+            if result not in ["timeout action", "cancelled action", "failed action"]:
+                if result is not None:
+                    with self._lock:
+                        self._task_results[task_id] = [result, time.time()]
+                else:
+                    with self._lock:
+                        self._task_results[task_id] = ["completed action", time.time()]
                 task_status_manager.add_task_status(task_id, None, "completed", None, time.time(), None, None, None)
+            else:
+                with self._lock:
+                    self._task_results[task_id] = [result, time.time()]
         finally:
             # Ensure the Future object is deleted
             with self._lock:
@@ -310,8 +323,8 @@ class TimerTask:
                     self._task_queue.put((execution_time, timeout_processing, task_name, task_id, func, args, kwargs))
                 except ValueError:
                     # If task_name is not a valid time string, do not reschedule
-                    logger.debug(
-                        f"Timer task | {task_id} | task_name is not a valid time string, not rescheduling")
+                    logger.error(
+                        f"task | {task_id} | task_name is not a valid time string, not rescheduling")
 
             # Check if all tasks are completed
             with self._lock:
@@ -327,6 +340,7 @@ class TimerTask:
             if self._idle_timer is not None:
                 self._idle_timer.cancel()
             self._idle_timer = threading.Timer(self._idle_timeout, self.stop_scheduler, args=(False, True,))
+            self._idle_timer.daemon = True
             self._idle_timer.start()
 
     def _cancel_idle_timer(self) -> None:
@@ -357,44 +371,63 @@ class TimerTask:
         """
         Force stop a task by its task ID.
 
-        :param task_id: Task ID.
+        Args:
+            task_id: Task ID.
 
-        :return: bool: Whether the task was successfully force stopped.
+        Returns:
+            Whether the task was successfully force stopped.
         """
         if self._running_tasks.get(task_id, None):
-            logger.debug(f"Timer task | {task_id} | does not exist or is already completed")
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
             return False
         future = self._running_tasks[task_id][0]
         if not future.running():
             future.cancel()
         else:
+            # First ensure that the task is not paused.
+            _task_manager.resume_task(task_id)
             _task_manager.terminate_task(task_id)
 
         task_status_manager.add_task_status(task_id, None, "cancelled", None, None, None, None, None)
-        with self._lock:
-            if task_id in self._task_results:
-                del self._task_results[task_id]
         return True
 
-    def pause_and_resume_task(self,
-                              task_id: str, action: str) -> bool:
+    def pause_task(self,
+                   task_id: str) -> bool:
         """
-        Pause and resume a task by its task ID.
-        :param task_id: Task ID.
-        :param action: Task action.
-        :return: bool: Whether the task was successfully pause and resume.
+        Pause a task by its task ID.
+
+        Args:
+            task_id: Task ID.
+
+        Returns:
+            Whether the task was successfully paused.
         """
-        if not self._running_tasks.get(task_id, None):
-            logger.debug(f"Timer task | {task_id} | does not exist or is already completed")
+        if self._running_tasks.get(task_id) is None and not config["thread_management"]:
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
             return False
 
-        else:
-            if action == "pause":
-                _task_manager.pause_task(task_id)
-                task_status_manager.add_task_status(task_id, None, "waiting", None, None, None, None, None)
-            elif action == "resume":
-                _task_manager.resume_task(task_id)
-                task_status_manager.add_task_status(task_id, None, "running", None, None, None, None, None)
+        _task_manager.pause_task(task_id)
+        task_status_manager.add_task_status(task_id, None, "paused", None, None, None, None, None)
+
+        return True
+
+    def resume_task(self,
+                    task_id: str) -> bool:
+        """
+        Resume a task by its task ID.
+
+        Args:
+            task_id: Task ID.
+
+        Returns:
+            Whether the task was successfully resumed.
+        """
+        if self._running_tasks.get(task_id) is None and not config["thread_management"]:
+            logger.warning(f"task | {task_id} | does not exist or is already completed")
+            return False
+
+        _task_manager.resume_task(task_id)
+        task_status_manager.add_task_status(task_id, None, "running", None, None, None, None, None)
 
         return True
 
@@ -404,13 +437,18 @@ class TimerTask:
         """
         Get the result of a task. If there is a result, return and delete the oldest result; if no result, return None.
 
-        :param task_id: Task ID.
+        Args:
+            task_id: Task ID.
 
-        :return: Optional[Any]: Task return result, or None if the task is not completed or does not exist.
+        Returns:
+            Task return result, or None if the task is not completed or does not exist.
         """
         if task_id in self._task_results:
-            result = self._task_results[task_id]
+            result = self._task_results[task_id][0]
             with self._lock:
                 del self._task_results[task_id]
             return result
         return None
+
+
+timer_task = TimerTask()
