@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
 # Author: fallingmeteorite
-
 import threading
 import time
 
+from typing import Union
 
-def interruptible_sleep(seconds: float or int) -> None:
+
+def interruptible_sleep(seconds: Union[float, int]) -> None:
     """
     Sleep for a specified number of seconds, but can be interrupted by setting an event.
 
     Args:
-        seconds (float or int): Number of seconds to sleep.
+        seconds: Number of seconds to sleep.
     """
     _event = threading.Event()
 
@@ -24,4 +25,4 @@ def interruptible_sleep(seconds: float or int) -> None:
     while not _event.is_set():
         _event.wait(0.1)
 
-    _thread.join(timeout=0)
+    _thread.join(timeout=0)
\ No newline at end of file
